@@ -2,6 +2,7 @@
 
 import argparse
 import os, sys
+import json
 
 from rich.console import Console
 
@@ -28,12 +29,43 @@ def main():
 
     elif args.file:
         data = commands_dict["fromfile"](args.file)
-        args.Language = lang_extensions[args.file[args.file.rfind(".")+1:]]
-    
+        args.Language = lang_extensions[args.file[args.file.rfind(".") + 1 :]]
+
     elif args.editor:
+        if args.Language == "none":
+            args.Language = Utils.lang_prompt()
         data = commands_dict["frombuffer"](args.Language, args.editor)
 
     else:
+        if args.Language == "none":
+            args.Language = Utils.lang_prompt()
+
+        if sys.platform == "linux" or sys.platform == "darwin":
+            path = f"{os.environ.get('HOME', '')}/.config"
+            if not os.path.isdir(path):
+                os.mkdir(f"{os.environ.get('HOME', '')}/.config")
+        elif "win" in sys.platform:
+            path = os.getenv("APPDATA") + os.sep + ".wand"
+            if not os.path.isdir(path):
+                os.mkdir(path)
+        try:
+            content = open(f"{path}/wand.json")
+        except FileNotFoundError:
+            open(f"{path}/wand.json", "a")
+            content = ""
+
+        if not content or not content.read():
+            with open(f"{path}/wand.json", "w") as config:
+                json.dump({"theme": args.theme}, config)
+        elif not args.theme:
+            content = open(f"{path}/wand.json")
+            args.theme = json.load(content)["theme"]
+        else:
+            file = open(f"{path}/wand.json")
+            content = json.load(file)
+            content["theme"] = args.theme
+            json.dump(content, open(f"{path}/wand.json", "w"))
+
         data = commands_dict["frominput"](args.theme, args.Language)
 
     width = os.get_terminal_size().columns - 5
@@ -42,7 +74,7 @@ def main():
         if data.get("status") == "0":
             output = data["program_output"].strip()
             console.print(
-                f"\nYour {args.Language} code ran successfully UwU", style="green"
+                f"\nYour {args.Language} code ran successfully", style="green"
             )
 
             console.print(Utils.print_msg_box(output, width=width))
@@ -50,7 +82,8 @@ def main():
         elif data.get("signal") == "Killed":
             output = data["program_output"][:100].strip()
             console.print(
-                "\nYour {args.Language} code ran successfully with status Killed", style="yellow"
+                "\nYour {args.Language} code ran successfully with status Killed",
+                style="yellow",
             )
             console.print(Utils.print_msg_box(output, width=width))
             console.print("Truncated, output is too long", style="yellow")
@@ -60,7 +93,7 @@ def main():
                 if "error" in k:
                     output = data[k].strip()
                     break
-            console.print(f"\nYour {args.Language} code errored out ;(", style="red")
+            console.print(f"\nYour {args.Language} code errored out :(", style="red")
             console.print(Utils.print_msg_box(output, width=width))
     except KeyError:
         console.print(Utils.print_msg_box("No output", width=width))
