@@ -1,7 +1,14 @@
-import sys, os
+import os
+import sys
+
+from rich.console import Console
+from wandbox.utilities.compilers import compilers_
 
 
 class Utils:
+    def __init__(self):
+        self.console = Console()
+
     def close(self):
         """Exit the program."""
         try:
@@ -9,6 +16,13 @@ class Utils:
         except SystemExit:
             os._exit(1)
 
+    def lang_prompt(self):
+        """Prompt the user for a language."""
+        language = self.console.input("[green]Enter your language:[/green] ")
+        if language not in compilers_:
+            self.console.print("Language is not supported!", style="bold red")
+        return language
+
     def print_msg_box(self, msg, indent=1, width=None, title=None):
         """Print message-box with optional title."""
         lines = msg.split("\n")
@@ -16,8 +30,8 @@ class Utils:
 
         for line in lines:
             if len(line) > width:
-                for trimmed in range((len(line)//width)+1):
-                    true_lines.append(line[width*trimmed:width+(trimmed*width)])
+                for trimmed in range((len(line) // width) + 1):
+                    true_lines.append(line[width * trimmed : width + (trimmed * width)])
             else:
                 true_lines.append(line)
 
